@@ -1,7 +1,7 @@
 """Library to handle connection with Switchbot."""
 from __future__ import annotations
 
-from bleak_retry_connector import get_device, close_stale_connections
+from bleak_retry_connector import close_stale_connections, get_device
 
 from .adv_parser import SwitchbotSupportedType, parse_advertisement_data
 from .const import SwitchbotModel
